
// Weather Station Sculpture Code by AW - 2021

// Based off of Instructables Internet of Things Class sample code
// Circuit Displays Internet Data
// Weather data is collected in a feed
//
// Modified by Becky Stern 2017
// based on the Adafruit IO Subscription Example

// Adafruit invests time and resources providing this open source code.
// Please support Adafruit and open source hardware by purchasing
// products from Adafruit!
//
// Written by Todd Treece for Adafruit Industries
// Copyright (c) 2016 Adafruit Industries
// Licensed under the MIT license.
//
// All text above must be included in any redistribution.

/************************ Adafruit IO Configuration *******************************/

// visit io.adafruit.com if you need to create an account,
// or if you need your Adafruit IO key.
#define IO_USERNAME    "-------"
#define IO_KEY         "-------"

/******************************* WIFI Configuration **************************************/

#define WIFI_SSID       "-------"
#define WIFI_PASS       "-------"

#include <AdafruitIO_WiFi.h>
AdafruitIO_WiFi io(IO_USERNAME, IO_KEY, WIFI_SSID, WIFI_PASS);

/************************ Main Program Starts Here *******************************/
#include <ESP8266WiFi.h>
#include <AdafruitIO.h>
#include <Adafruit_MQTT.h>
#include <ArduinoHttpClient.h>

#define LED_PIN 13

// 1 = ON, 0 = OFF
int rainOn = 0;
int snowOn = 0;
int sunOn = 0;
int cloudOn = 0;
int mostlyCloudOn = 0;

const int rain1Pin = 4;
const int rain2Pin = 13;
const int snow1Pin = 16;
const int snow2Pin = 5;
const int sun1Pin = 9;
const int sun2Pin = 14;
const int cloudPin = 15;

AdafruitIO_Feed *weather = io.feed("weather"); // set up the 'weather' feed

void setup() {

  // start the serial connection
  Serial.begin(115200);

  // connect to io.adafruit.com
  Serial.print("Connecting to Adafruit IO");

  io.connect();

  pinMode(rain1Pin, OUTPUT);
  pinMode(rain2Pin, OUTPUT);
  pinMode(LED_BUILTIN, OUTPUT);
  pinMode(snow1Pin, OUTPUT);
  pinMode(sun1Pin, OUTPUT);
  pinMode(snow2Pin, OUTPUT);
  pinMode(sun2Pin, OUTPUT);
  pinMode(cloudPin, OUTPUT);

  // set up a message handler for the 'weather' feed.
  // the handleMessage function (defined below)
  // will be called whenever a message is
  // received from adafruit io.
  weather->onMessage(handleMessage);

  // wait for a connection
  while (io.status() < AIO_CONNECTED) {
    Serial.print(".");
    delay(500);
  }
  // we are connected
  Serial.println();
  Serial.println(io.statusText());

}

void loop() {

  // io.run(); is required for all sketches.
  // it should always be present at the top of your loop
  // function. It keeps the client connected to
  // io.adafruit.com, and processes any incoming data.
  io.run();
  if (rainOn == 1) {
    digitalWrite(cloudPin, HIGH);
    digitalWrite(rain1Pin, HIGH);
    digitalWrite(rain2Pin, LOW);
    delay(500);
    digitalWrite(rain2Pin, HIGH);
    digitalWrite(rain1Pin, LOW);
    delay(500);
  }
  else if (snowOn == 1) {
    digitalWrite(cloudPin, HIGH);
    digitalWrite(snow1Pin, HIGH);
    digitalWrite(snow2Pin, LOW);
    delay(1000);
    digitalWrite(snow2Pin, HIGH);
    digitalWrite(snow1Pin, LOW);
    delay(1000);
  }
  else if (sunOn == 1) {
    digitalWrite(sun1Pin, HIGH);
    digitalWrite(sun2Pin, HIGH);
  }
  else if (cloudOn == 1) {
    digitalWrite(cloudPin, HIGH);
  }
  else if (mostlyCloudOn == 1) {
    digitalWrite(sun1Pin, HIGH);
    delay(10);
    digitalWrite(cloudPin, HIGH);
  }
}

// this function is called whenever a message
// is received from Adafruit IO. it was attached to
// the feed in the setup() function above.
void handleMessage(AdafruitIO_Data *data) {

  String forecast = data->toString(); // store the incoming weather data in a string

  Serial.print("received <- ");
  Serial.println(forecast);

  digitalWrite(cloudPin, LOW);
  digitalWrite(rain1Pin, LOW);
  digitalWrite(rain2Pin, LOW);
  digitalWrite(sun1Pin, LOW);
  digitalWrite(sun2Pin, LOW);
  digitalWrite(snow1Pin, LOW);
  digitalWrite(snow2Pin, LOW);

  //the following strings store the varous IFTTT weather report words
  String rain = String("Rain");
  String lightrain = String("Light Rain");
  String rainshower = String ("Rain Shower");
  String AMshowers = String ("AM Showers");
  String Showers = String ("Showers");


  String rainandsnow = String("Rain and Snow");
  String snow = String("Snow");
  String snowshower = String("Snow Shower");

  String cloudy = String("Cloudy");
  String mostlycloudy = String("Mostly Cloudy");
  String partlycloudy = String("Partly Cloudy");

  String clearsky = String("Clear");
  String fair = String("Fair");
  String sunny = String("Sunny");

  // These if statements compare the incoming weather variable to the stored conditions

  // if there's rain in the forecast
  if (forecast.equalsIgnoreCase(rain) || forecast.equalsIgnoreCase(lightrain) || forecast.equalsIgnoreCase(Showers) || forecast.equalsIgnoreCase(rainshower) || forecast.equalsIgnoreCase(AMshowers)) {
    rainOn = 1;
  }
  else {
    rainOn = 0;
  }

  // if there's snow in the forecast
  if (forecast.equalsIgnoreCase(snow) || forecast.equalsIgnoreCase(rainandsnow) || forecast.equalsIgnoreCase(snowshower)) {
    snowOn = 1;
  }
  else {
    snowOn = 0;
  }

  // if there's sun in the forecast
  if (forecast.equalsIgnoreCase(clearsky) || forecast.equalsIgnoreCase(fair) || forecast.equalsIgnoreCase(sunny)) {
    sunOn = 1;
  }
  else {
    sunOn = 0;
  }

  // if there're clouds in the forecast
  if (forecast.equalsIgnoreCase(cloudy)) {
    cloudOn = 1;
  }
  else {
    cloudOn = 0;
  }
  // if there're clouds in the forecast
  if (forecast.equalsIgnoreCase(mostlycloudy) || forecast.equalsIgnoreCase(partlycloudy)) {
    mostlyCloudOn = 1;
  }
  else {
    mostlyCloudOn = 0;
  }

  digitalWrite(LED_BUILTIN, HIGH);  // Turn the LED off by making the voltage HIGH
  delay(1000);
  digitalWrite(LED_BUILTIN, LOW);   // Turn the LED on (Note that LOW is the voltage level
  // but actually the LED is on; this is because
  // it is active low on the ESP-01)
  delay(1000);                      // Wait for a second
  digitalWrite(LED_BUILTIN, HIGH);  // Turn the LED off by making the voltage HIGH
  delay(500);

}
